@@ -1,9 +1,9 @@
 # -*- coding: utf-8 -*-
 
 from .getswag import swag
-from .httppool_server import resp, excp, checkpath, parseApiArgs, unauthorized
+from .httppool_server import resp, excp, checkpath, unauthorized
 from ..model.user import auth
-from ...dataset.serializable import serialize
+from ...dataset.deserialize import deserialize_args
 from ...pal.poolmanager import PoolManager as PM, DEFAULT_MEM_POOL
 from ...pal.webapi import WebAPI
 
@@ -557,10 +557,10 @@ def get_prod_count(prod_type, pool_id):
 ######################################
 
 
-@ pools_api.route('/<string:pool>/api/<string:method>', methods=['GET'])
-@ pools_api.route('/<string:pool>/api/<string:method>/<path:args>', methods=['GET'])
+@ pools_api.route('/<string:pool>/api/<string:method_args>', methods=['GET'])
+@ pools_api.route('/<string:pool>/api/<string:method_args>/', methods=['GET'])
 @ auth.login_required
-def api(pool, method, args=None):
+def api(pool, method_args):
     """ Call api mathods on the running pool and returns the result.
 
     """
@@ -568,17 +568,11 @@ def api(pool, method, args=None):
     logger = current_app.logger
 
     ts = time.time()
-    logger.debug(f'get API {method}({args}) for {pool}')
+    logger.debug(f'get API {method_args} for {pool}')
 
-    if args is None:
-        args = ''
-
-    paths = [pool, 'api', method] + args.split('/')
+    paths = [pool, 'api', method_args]
     lp0 = len(paths)
 
-    # if paths[-1] == '':
-    #    del paths[-1]
-
     code, result, msg = call_pool_Api(paths, serialize_out=False)
 
     return resp(code, result, msg, ts, serialize_out=False)
@@ -594,34 +588,34 @@ def call_pool_Api(paths, serialize_out=False):
     logger = current_app.logger
     ts = time.time()
 
-    # index of method name
-    ind_meth = 2
-    # remove empty trailing strings
-    for o in range(len(paths), 1, -1):
-        if paths[o-1]:
-            break
+    args, kwds = [], {}
 
-    paths = paths[:o]
-    lp = len(paths)
-    method = paths[ind_meth]
+    # the unquoted args. may have ',' in strings
+    #quoted_m_args = paths[ind_meth+1]
+
+    # from the unquoted url extract the fist path segment.
+    quoted_m_args = request.url.split(
+        paths[0] + '/' + paths[1] + '/')[1].strip('/')
+    logger.debug(f'get API {quoted_m_args}')
+    # get command positional arguments and keyword arguments
+    code, m_args, kwds = deserialize_args(
+        quoted_m_args, serialize_out=serialize_out)
+    if code != 200:
+        result, msg = m_args, kwds
+        return 0, resp(422, result, msg, ts, serialize_out=False), 0
+
+    method = m_args[0]
+    # if 'getPoolurl' in method:
+    #    __import__('pdb').set_trace()
     if method not in WebAPI:
         return 0, resp(400, FAILED,
                        'Unknown web API method: %s.' % method,
                        ts, serialize_out=False), 0
-    args, kwds = [], {}
-
-    all_args = paths[ind_meth+1:]
-    if lp > ind_meth:
-        # get command positional arguments and keyword arguments
-        code, args, kwds = parseApiArgs(all_args, serialize_out=serialize_out)
-        if code != 200:
-            result, msg = args, kwds
-            return 0, resp(422, result, msg, ts, serialize_out=False), 0
-        else:
-            kwdsexpr = [str(k)+'='+str(v) for k, v in kwds.items()]
-            msg = '%s(%s)' % (method, ', '.join(
-                chain(map(str, args), kwdsexpr)))
-            logger.debug('WebAPI ' + msg)
+    args = m_args[1:] if len(m_args) > 1 else []
+    kwdsexpr = [str(k)+'='+str(v) for k, v in kwds.items()]
+    msg = '%s(%s)' % (method, ', '.join(
+        chain(map(str, args), kwdsexpr)))
+    logger.debug('WebAPI ' + msg)
 
     poolname = paths[0]
     poolurl = current_app.config['POOLURL_BASE'] + poolname
