@@ -14,7 +14,6 @@ from fdi.pal.productstorage import ProductStorage
 from fdi.pal.productpool import Lock_Path_Base
 from fdi.utils.common import lls, trbk, fullname
 from fdi.utils.fetch import fetch
-from fdi.httppool.route import httppool_server
 from fdi.pns.jsonio import auth_headers
 
 import pytest
@@ -382,6 +381,8 @@ def test_CRUD_product(local_pools_dir, server, userpass, client):
 
     files1 = [f for f in get_files_in_local_dir(
         post_poolid, local_pools_dir) if f[-1].isnumeric()]
+    # list of would-be urns from existing files.
+    urns1 = ['urn:' + post_poolid + ':' + x.replace('_', ':') for x in files1]
     num_prod = len(files1)
     assert num_prod == len(creators) + origin_prod, 'Products number not match'
 
@@ -422,7 +423,7 @@ def test_CRUD_product(local_pools_dir, server, userpass, client):
         assert o['result']['classes'][prodt]['sn'][-l:] == inds
         assert o['result']['classes'][prodt]['currentSN'] == inds[-1]
         assert len(o['result']['tags']) == 0
-        assert set(o['result']['urns'].keys()) == set(urns)
+        assert set(o['result']['urns'].keys()) == set(urns1)
 
     logger.info('read classes')
     hkpath = '/hk/classes'
@@ -435,7 +436,7 @@ def test_CRUD_product(local_pools_dir, server, userpass, client):
 
     logger.info('check count')
     num = len(o['result'][prodt]['sn'])
-    apipath = '/api/getCount/' + prodt
+    apipath = '/api/getCount__' + prodt
     url = aburl + '/' + post_poolid + apipath
     x = client.get(url, auth=auth)
     o = getPayload(x)
@@ -457,7 +458,7 @@ def test_CRUD_product(local_pools_dir, server, userpass, client):
     o = getPayload(x)
     check_response(o)
 
-    assert set(o['result'].keys()) == set(urns)
+    assert set(o['result'].keys()) == set(urns1)
 
     # ========
     logger.info('delete a product')
@@ -571,7 +572,7 @@ def test_product_path(server, userpass, client):
     pt = urn.split(':', 2)[2].replace(':', '/')
 
     urlp = url0 + pt
-    # http://0.0.0.0:5000/v0.7/fdi_serv.test_httppool/fdi.dataset.product.Product/0/results/Time_Energy_Pos/Energy/data
+    # http://127.0.0.1:5000/v0.9/fdi_serv.test_httppool/fdi.dataset.product.Product/0/results/Time_Energy_Pos/Energy/data
     url3 = urlp + '/' + pth
     x = client.get(url3, auth=auth)
     o = getPayload(x)
@@ -596,6 +597,7 @@ def test_product_path(server, userpass, client):
         assert c == f
     # members
 
+    # pt = fdi.dataset.product.Product/0
     url = url0 + pt + '/'
     x = client.get(url, auth=auth)
     o = getPayload(x)
@@ -606,7 +608,7 @@ def test_product_path(server, userpass, client):
     # string
 
     # 'http://127.0.0.1:5000/v0.9/fdi_serv.test_httppool/string/fdi.dataset.product.Product/0'
-    url = url0 + pt + '/$string'
+    url = url0 + pt + '/toString'
     x = client.get(url, auth=auth)
     assert x.headers['Content-Type'] == 'text/plain'
     c = getPayload(x)
